@@ -384,8 +384,8 @@ impl<'a> ParserBuilder<'a> {
                 DisplayFormatPart::Str(s) => self.push_str(s),
                 DisplayFormatPart::EscapedBeginBracket => self.push_str("{"),
                 DisplayFormatPart::EscapedEndBracket => self.push_str("}"),
-                DisplayFormatPart::Var { name, .. } => {
-                    let keys = FieldKey::from_str_deep(&name);
+                DisplayFormatPart::Var { arg, .. } => {
+                    let keys = FieldKey::from_str_deep(&arg);
                     if let DisplayContext::Variant { variant, style } = context {
                         if keys.is_empty() {
                             self.push_str(&style.apply(&variant.ident));
@@ -918,9 +918,9 @@ impl DisplayFormat {
                 continue;
             }
             if let Some(c) = REGEX_VAR.captures(s) {
-                let name = c.get(1).unwrap().as_str().into();
-                let parameters = c.get(2).map_or("", |x| x.as_str()).into();
-                parts.push(DisplayFormatPart::Var { name, parameters });
+                let arg = c.get(1).unwrap().as_str().into();
+                let format_spec = c.get(2).map_or("", |x| x.as_str()).into();
+                parts.push(DisplayFormatPart::Var { arg, format_spec });
                 s = &s[c.get(0).unwrap().end()..];
                 continue;
             }
@@ -930,8 +930,8 @@ impl DisplayFormat {
     }
     fn from_newtype_struct(data: &DataStruct) -> Option<Self> {
         let p = DisplayFormatPart::Var {
-            name: get_newtype_field(data)?,
-            parameters: String::new(),
+            arg: get_newtype_field(data)?,
+            format_spec: String::new(),
         };
         Some(Self {
             parts: vec![p],
@@ -960,13 +960,16 @@ impl DisplayFormat {
                 Str(s) => format_str.push_str(s.as_str()),
                 EscapedBeginBracket => format_str.push_str("{{"),
                 EscapedEndBracket => format_str.push_str("}}"),
-                Var { name, parameters } => {
-                    format_str.push_str("{:");
-                    format_str.push_str(&parameters);
+                Var { arg, format_spec } => {
+                    format_str.push('{');
+                    if !format_spec.is_empty() {
+                        format_str.push(':');
+                        format_str.push_str(&format_spec);
+                    }
                     format_str.push('}');
                     format_args.push(context.format_arg(
-                        &name,
-                        &parameters,
+                        &arg,
+                        &format_spec,
                         self.span,
                         bounds,
                         generics,
@@ -974,6 +977,7 @@ impl DisplayFormat {
                 }
             }
         }
+        let format_str = LitStr::new(&format_str, self.span);
         Ok(quote! { #format_str #(,#format_args)* })
     }
 }
@@ -983,7 +987,7 @@ enum DisplayFormatPart {
     Str(String),
     EscapedBeginBracket,
     EscapedEndBracket,
-    Var { name: String, parameters: String },
+    Var { arg: String, format_spec: String },
 }
 
 enum DisplayContext<'a> {
@@ -1004,18 +1008,24 @@ enum DisplayContext<'a> {
 impl<'a> DisplayContext<'a> {
     fn format_arg(
         &self,
-        name: &str,
-        parameters: &str,
+        arg: &str,
+        format_spec: &str,
         span: Span,
         bounds: &mut Bounds,
         generics: &GenericParamSet,
     ) -> Result<TokenStream> {
-        let keys = FieldKey::from_str_deep(name);
+        let keys = FieldKey::from_str_deep(arg);
         if keys.is_empty() {
             return Ok(match self {
                 DisplayContext::Struct { .. } => bail!(span, "{} is not allowed in struct format."),
-                DisplayContext::Field { parent, field, key } => parent
-                    .format_arg_by_field_expr(key, field, parameters, span, bounds, generics)?,
+                DisplayContext::Field { parent, field, key } => parent.format_arg_by_field_expr(
+                    key,
+                    field,
+                    format_spec,
+                    span,
+                    bounds,
+                    generics,
+                )?,
                 DisplayContext::Variant { variant, style } => {
                     let s = style.apply(&variant.ident);
                     quote! { #s }
@@ -1032,7 +1042,7 @@ impl<'a> DisplayContext<'a> {
                 } else {
                     bail!(span, "unknown field '{}'.", key);
                 };
-                return self.format_arg_of_field(key, field, parameters, span, bounds, generics);
+                return self.format_arg_of_field(key, field, format_spec, span, bounds, generics);
             }
         }
         let mut expr = self.field_expr(&keys[0]);
@@ -1071,16 +1081,16 @@ impl<'a> DisplayContext<'a> {
         &self,
         key: &FieldKey,
         field: &Field,
-        parameters: &str,
+        format_spec: &str,
         span: Span,
         bounds: &mut Bounds,
         generics: &GenericParamSet,
     ) -> Result<TokenStream> {
         let ty = &field.ty;
         if generics.contains_in_type(ty) {
-            let ps = match FormatParameters::parse(&parameters) {
+            let ps = match FormatSpec::parse(&format_spec) {
                 Ok(ps) => ps,
-                Err(_) => bail!(span, "invalid format parameters \"{}\".", parameters),
+                Err(_) => bail!(span, "invalid format parameters \"{}\".", format_spec),
             };
             let tr = ps.format_type.trait_name();
             let tr: Ident = parse_str(tr).unwrap();
